% Compute classification accuracy of BNC model on LOB data
%% Init
clear;

load 'statistics_ws250.mat' C5tags C5counts classCode;
load 'statistics_ws250.mat' AWL ASL TTR NHL nwords;

nouns = strcmp(C5tags,'NN0')|strcmp(C5tags,'NN1')|...
    strcmp(C5tags,'NN2')|strcmp(C5tags,'NP0');
pronouns = strcmp(C5tags,'PNP')|strcmp(C5tags,'PNX');

NR = sum(C5counts(:,nouns),2) ./ nwords;
PR = sum(C5counts(:,pronouns),2) ./ nwords;

X = [NR PR AWL ASL TTR NHL];

clear C5tags C5counts NR PR AWL ASL TTR NHL nouns pronouns;

% Extract classes
simpleClass = zeros(length(classCode),1);
for i = 1:length(classCode)
    cc = classCode{i};
    if(strfind(cc,'W fict prose'))
        simpleClass(i) = 2;
    elseif(strfind(cc,'W newsp brdsht'))
        simpleClass(i) = 3;
    elseif(strfind(cc,'W ac'))
        simpleClass(i) = 4;
    elseif(strfind(cc,'S conv'))
        simpleClass(i) = 1;
    end
end

clear i cc classCode;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

% Select appropriate data
X1 = X(:,[2 1]);
X2 = X(:,[3 5]);

% Add cross-terms
X1 = [X1 X1(:,1).*1.88+X1(:,2) X1(:,1).*1.88-X1(:,2)];
X2 = [X2 X2(:,1)+X2(:,2).*7.98 X2(:,1)-X2(:,2).*7.98];

clear index nwords M simpleClass i X;

%% Compute and plot decision tree for NR,PR and AWL,TTR
t1 = classregtree(X1,y,'minleaf',30,'surrogate','on');
t2 = classregtree(X2,y,'minleaf',30,'surrogate','on');

%% Init
clear X1 X2 y;

load statistics_LOB_ws250.mat POScounts AWL TTR nwords genreindex;

nouns = 58:86;
pronouns = 92:104; % Checked

NR = sum(POScounts(:,nouns),2) ./ nwords;
PR = sum(POScounts(:,pronouns),2) ./ nwords;

X = [NR PR AWL TTR];

clear POScounts AWL TTR nouns pronouns NR PR;

% Extract classes 
simpleClass = zeros(500,1);
simpleClass(ismember(genreindex,1:3)) = 2; % Newspaper
simpleClass(ismember(genreindex,9)) = 3; % Academic
simpleClass(ismember(genreindex,10:14)) = 1; % Fiction

clear genreindex;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

% Select appropriate data
X1 = X(:,[2 1]);
X2 = X(:,[3 4]);

% Add cross-terms
X1 = [X1 X1(:,1).*1.88+X1(:,2) X1(:,1).*1.88-X1(:,2)];
X2 = [X2 X2(:,1)+X2(:,2).*7.98 X2(:,1)-X2(:,2).*7.98];

clear index nwords M simpleClass i X;

%% Compute cross-corpus score
CM1 = zeros(4,4);
CM2 = zeros(4,4);

yfit1 = eval(t1,X1); %#ok<EVLC>
yfit2 = eval(t2,X2); %#ok<EVLC>
    
for j = 1:length(yfit1)
    ypred = str2double(yfit1{j});
    CM1(y(j),ypred) = CM1(y(j),ypred) + 1;
    ypred = str2double(yfit2{j});
    CM2(y(j),ypred) = CM2(y(j),ypred) + 1;
end

CM1 = CM1([4 1 2 3],:);
CM2 = CM2([4 1 2 3],:);

clear yfit1 yfit2 j ypred;

%% Print error rates for both pairs
n = sum(sum(CM1));
error1 = n - sum(diag(CM1));
error2 = n - sum(diag(CM2));

fprintf('%s\n',['Error for model 1: ' num2str(error1) ' (' num2str(100*error1/n) ' %)']);
fprintf('%s\n',['Error for model 2: ' num2str(error2) ' (' num2str(100*error2/n) ' %)']);