% Compute cross-validation classification scores
%% Init
clear;

load statistics_ws250.mat AWL ASL TTR NHL nwords C5tags C5counts classCode;

nouns = strcmp(C5tags,'NN0')|strcmp(C5tags,'NN1')|...
    strcmp(C5tags,'NN2')|strcmp(C5tags,'NP0');
pronouns = strcmp(C5tags,'PNP')|strcmp(C5tags,'PNX');

NR = sum(C5counts(:,nouns),2) ./ nwords;
PR = sum(C5counts(:,pronouns),2) ./ nwords;

X = [NR PR AWL ASL TTR NHL];

clear C5tags C5counts NR PR AWL ASL TTR NHL nouns pronouns;

% Extract classes
simpleClass = extractClass(classCode);
clear classCode;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

clear index nwords M simpleClass i;

%% Run experiments
% Note X = [NR PR AWL ASL TTR NHL]
expindex = {[1 2],[1 3],[1 4],[1 5],[1 6],...
    [2 3],[2 4],[2 5],[2 6],[3 4],[3 5],[3 6],...
    [4 5],[4 6],[5 6]};

nfold = length(y);
minleaf = 30;

CMtree = cell(length(expindex),1);
treeErr = zeros(length(expindex),1);

tic;

parfor i = 1:length(expindex)
    % Select appropriate data
    Xexp = X(:,expindex{i}); %#ok<PFBNS>
    
    % Add cross-terms
    ratio = (max(Xexp(:,1))-min(Xexp(:,1)))/...
        (max(Xexp(:,2))-min(Xexp(:,2)));
    Xexp = [Xexp Xexp(:,1)+ratio*Xexp(:,2) Xexp(:,1)-ratio*Xexp(:,2)];
    
    % Train and test classification tree
    CMtreei = classificationTreeCV(Xexp, y, nfold, minleaf);
    CMtree{i} = CMtreei;
    
    % Compute error rate
    err = length(y) - sum(diag(CMtreei));
    fprintf('%s\n',['Error classification tree (' num2str(expindex{i}) ...
        '): ' num2str(err) ' (' num2str(err/length(y)*100) ' %)']);
    treeErr(i) = err;
end

ctime = toc;
fprintf('%s\n',['Experiments finished in ' num2str(ctime/60) ' minutes.']);

clear err CMtreei CMknni;

% save experiments-DT-Cross.mat

%% Analysis of experiments
ninputs = zeros(length(expindex),1);
for i = 1:length(expindex)
    ninputs(i) = length(expindex{i});
end

clear i;

% Print accuracy for all pairs
index = find(ninputs == 2 | ninputs == 1);
fprintf('%s\n','Index  Inputs      Tree Accuracy');
for i = 1:length(index)
    fprintf('%s\n',[num2str(index(i)) '      ' ...
        num2str(expindex{index(i)}) '        ' ...
        num2str((length(y)-treeErr(index(i)))*100/length(y),'%2.1f') ...
        '         ']);
end

clear index i;