% Compute cross-validation classification scores
%% Init
clear;

load statistics_LOB_ws250.mat POScounts AWL ASL TTR NHL nwords genreindex;

nouns = 58:86;
pronouns = 92:104; % Checked

NR = sum(POScounts(:,nouns),2) ./ nwords;
PR = sum(POScounts(:,pronouns),2) ./ nwords;

X = [NR PR AWL ASL TTR NHL];

clear POScounts NR PR AWL ASL TTR NHL nouns pronouns;

% Extract classes 
simpleClass = zeros(500,1);
simpleClass(ismember(genreindex,1:3)) = 2; % Newspaper
simpleClass(ismember(genreindex,9)) = 3; % Academic
simpleClass(ismember(genreindex,10:14)) = 1; % Fiction

clear genreindex;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

clear index nwords M simpleClass i;

%% Run experiments
% Note X = [NR PR AWL ASL TTR NHL]
expindex = {[1 2],[1 3],[1 4],[1 5],[1 6],...
    [2 3],[2 4],[2 5],[2 6],[3 4],[3 5],[3 6],...
    [4 5],[4 6],[5 6]};

nfold = length(y);
minleaf = 30;

CMtree = cell(length(expindex),1);
treeErr = zeros(length(expindex),1);

tic;

parfor i = 1:length(expindex)
    % Select appropriate data
    Xexp = X(:,expindex{i}); %#ok<PFBNS>
    
    % Add cross-terms
    ratio = (max(Xexp(:,1))-min(Xexp(:,1)))/...
        (max(Xexp(:,2))-min(Xexp(:,2)));
    Xexp = [Xexp Xexp(:,1)+ratio*Xexp(:,2) Xexp(:,1)-ratio*Xexp(:,2)];
    
    % Train and test classification tree
    CMtreei = classificationTreeCV(Xexp, y, nfold, minleaf);
    CMtree{i} = CMtreei;
    
    % Compute error rate
    err = length(y) - sum(diag(CMtreei));
    fprintf('%s\n',['Error classification tree (' num2str(expindex{i}) ...
        '): ' num2str(err) ' (' num2str(err/length(y)*100) ' %)']);
    treeErr(i) = err;
end

ctime = toc;
fprintf('%s\n',['Experiments finished in ' num2str(ctime/60) ' minutes.']);

clear err CMtreei CMknni;

save experiments-DT-Cross-LOB.mat

%% Analysis of experiments
ninputs = zeros(length(expindex),1);
for i = 1:length(expindex)
    ninputs(i) = length(expindex{i});
end

clear i;

% Print error rates for all pairs
index = find(ninputs == 2);
fprintf('%s\n','Index  Inputs      Tree Error');
for i = 1:length(index)
    fprintf('%s\n',[num2str(index(i)) '      ' ...
        num2str(expindex{index(i)}) '        ' ...
        num2str(treeErr(index(i))) '         ']);
end

clear index i;