% Plot decision tree plots
%% Init
clear;

load statistics_ws250.mat C5tags C5counts classCode;
load statistics_ws250.mat AWL ASL TTR NHL nwords;

nouns = strcmp(C5tags,'NN0')|strcmp(C5tags,'NN1')|...
    strcmp(C5tags,'NN2')|strcmp(C5tags,'NP0');
pronouns = strcmp(C5tags,'PNP')|strcmp(C5tags,'PNX');

NR = sum(C5counts(:,nouns),2) ./ nwords;
PR = sum(C5counts(:,pronouns),2) ./ nwords;

X = [NR PR AWL ASL TTR NHL];

clear C5tags C5counts NR PR AWL ASL TTR NHL nouns pronouns;

% Extract classes
simpleClass = extractClass(classCode);

clear classCode;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

% Select appropriate data
X1 = X(:,[2 1]);
X2 = X(:,[3 5]);

% Add cross-terms
X1 = [X1 X1(:,1).*1.88+X1(:,2) X1(:,1).*1.88-X1(:,2)];
X2 = [X2 X2(:,1)+X2(:,2).*7.98 X2(:,1)-X2(:,2).*7.98];

clear index nwords M simpleClass i X;

%% Compute and plot decision tree for NR,PR and AWL,TTR
t1 = classregtree(X1,y,'minleaf',30,'surrogate','on');
t2 = classregtree(X2,y,'minleaf',30,'surrogate','on');

%% Settings
markersize = 8.0;
facecolor{1} = [1.00 0.00 0.00]; % Conversation
facecolor{2} = [0.00 0.00 0.70]; % Fiction
facecolor{3} = [1.00 0.50 1.00]; % Newspaper
facecolor{4} = [0.30 1.00 0.30]; % Academic
%facecolor{1} = [0.55 0.55 0.55]; % Conversation
%facecolor{2} = [0.75 0.75 0.75]; % Fiction
%facecolor{3} = [0.95 0.95 0.95]; % Newspaper
%facecolor{4} = [0.40 0.40 0.40]; % Academic
%edgecolor{1} = facecolor{1}*0.8; % Conversation
edgecolor{1} = facecolor{1}*0.7; % Conversation
edgecolor{2} = facecolor{2}*0.7; % Fiction
%edgecolor{3} = facecolor{3}*0.8; % Newspaper
edgecolor{3} = [0.80 0.00 1.00]; % Newspaper
edgecolor{4} = facecolor{4}*0.85; % Academic
c1 = find(double(y) == 1);
c2 = find(double(y) == 2);
c3 = find(double(y) == 3);
c4 = find(double(y) == 4);
linewidth = 1.0;

%% Plot figures on colored background (to spot outliers)
figure('Name','Complexity Measures','Units','centimeters',...
    'OuterPosition',[0 3 26.0 26.0],'Resize','off',...
    'PaperOrientation','landscape','PaperType','A4');
% Plot 1
axes('Position', [.105, .085, .87, .89],'ActivePositionProperty',...
    'position','FontName','Helvetica','FontSize',18.0);
hold all;
% Alternative markers: p(+2) o s d
plot(X1(c4,1),X1(c4,2),'p','MarkerSize',markersize+2,'MarkerFaceColor',facecolor{4},'MarkerEdgeColor',edgecolor{4});
plot(X1(c1,1),X1(c1,2),'o','MarkerSize',markersize,'MarkerFaceColor',facecolor{1},'MarkerEdgeColor',edgecolor{1});
plot(X1(c2,1),X1(c2,2),'s','MarkerSize',markersize,'MarkerFaceColor',facecolor{2},'MarkerEdgeColor',edgecolor{2});
plot(X1(c3,1),X1(c3,2),'d','MarkerSize',markersize,'MarkerFaceColor',facecolor{3},'MarkerEdgeColor',edgecolor{3});
offset = floor(min(X1(:,1))*20)/20;
scale = ceil(max(X1(:,1))*20)/20 - offset;
x11 = offset+(0:0.25:1).*scale;
xlim([x11(1) x11(end)]);
set(gca,'XTick',x11);
offset = floor(min(X1(:,2))*20)/20;
scale = ceil(max(X1(:,2))*20)/20 - offset;
x12 = offset+(0:0.25:1).*scale;
ylim([x12(1) x12(end)]);
set(gca,'YTick',x12);
xlabel('Pronoun ratio');
ylabel('Noun ratio');

% Plot decision tree
plot([0.060 0.060],[0.000 0.500],'--k','LineWidth',linewidth); % 1
plot([0.000 0.060],[0.338 0.226],'--k','LineWidth',linewidth); % 2
plot([0.060 0.250],[0.148 0.148],'--k','LineWidth',linewidth); % 3
hold off;

legend({'Academic','Conversation','Fiction','Newspaper',...
    'Decision-tree'},'Orientation','vertical','Position',...
    [0.725 0.835 0.3 0.05]);
legend('boxoff');

% Plot 2
figure('Name','Complexity Measures','Units','centimeters',...
    'OuterPosition',[20 3 26.0 26.0],'Resize','off',...
    'PaperOrientation','landscape','PaperType','A4');
axes('Position', [.105, .085, .87, .89],'ActivePositionProperty',...
    'position','FontName','Helvetica','FontSize',18.0);
hold all;
% Alternative markers: p(+2) o s d
plot(X2(c4,1),X2(c4,2),'p','MarkerSize',markersize+2,'MarkerFaceColor',facecolor{4},'MarkerEdgeColor',edgecolor{4});
plot(X2(c1,1),X2(c1,2),'o','MarkerSize',markersize,'MarkerFaceColor',facecolor{1},'MarkerEdgeColor',edgecolor{1});
plot(X2(c2,1),X2(c2,2),'s','MarkerSize',markersize,'MarkerFaceColor',facecolor{2},'MarkerEdgeColor',edgecolor{2});
plot(X2(c3,1),X2(c3,2),'d','MarkerSize',markersize,'MarkerFaceColor',facecolor{3},'MarkerEdgeColor',edgecolor{3});
offset = floor(min(X2(:,1))*10)/10;
scale = ceil(max(X2(:,1))*10)/10 - offset;
x21 = offset+(0:0.25:1).*scale;
xlim([x21(1) x21(end)]);
set(gca,'XTick',x21);
offset = floor(min(X2(:,2))*50)/50;
scale = ceil(max(X2(:,2))*50)/50 - offset;
x22 = offset+(0:0.25:1).*scale;
ylim([x22(1) x22(end)]);
set(gca,'YTick',x22);
xlabel('Average word length');
ylabel('Type/token ratio');

% Plot decision tree
plot([3.000 6.000],[0.369 0.745],'--k','LineWidth',linewidth); % 1
plot([4.562 4.562],[0.565 0.800],'--k','LineWidth',linewidth); % 2
plot([3.000 3.973],[0.614 0.491],'--k','LineWidth',linewidth); % 4
hold off;

legend({'Academic','Conversation','Fiction','Newspaper',...
    'Decision-tree'},'Orientation','vertical','Position',...
    [0.100 0.835 0.3 0.05]);
legend('boxoff');