% Plot BNC-decision tree plots using LOB data
%% Init
clear;

load statistics_LOB_ws250.mat POScounts AWL TTR nwords genreindex;

nouns = 58:86;
pronouns = 88:105;
% pronouns = 95:105;

NR = sum(POScounts(:,nouns),2) ./ nwords;
PR = sum(POScounts(:,pronouns),2) ./ nwords;

X = [NR PR AWL TTR];

clear POScounts AWL TTR nouns pronouns NR PR;

% Extract classes 
simpleClass = zeros(500,1);
simpleClass(ismember(genreindex,1:3)) = 2; % Newspaper
simpleClass(ismember(genreindex,9)) = 3; % Academic
simpleClass(ismember(genreindex,10:13)) = 1; % Fiction

clear genreindex;

% Select text with at least X words
index = nwords >= 250 & simpleClass > 0;

X = X(index,:);

y = nominal(simpleClass(index));

% Select appropriate data
X1 = X(:,[2 1]);
X2 = X(:,[3 4]);

% Add cross-terms
X1 = [X1 X1(:,1).*1.88+X1(:,2) X1(:,1).*1.88-X1(:,2)];
X2 = [X2 X2(:,1)+X2(:,2).*7.98 X2(:,1)-X2(:,2).*7.98];

clear index nwords M simpleClass i X;

%% Settings
markersize = 8.0;
% facecolor{1} = [1.00 0.00 0.00]; % Conversation
facecolor{1} = [0.00 0.00 0.70]; % Fiction
facecolor{2} = [1.00 0.50 1.00]; % Newspaper
facecolor{3} = [0.30 1.00 0.30]; % Academic
%facecolor{1} = [0.55 0.55 0.55]; % Conversation
%facecolor{2} = [0.75 0.75 0.75]; % Fiction
%facecolor{3} = [0.95 0.95 0.95]; % Newspaper
%facecolor{4} = [0.40 0.40 0.40]; % Academic
%edgecolor{1} = facecolor{1}*0.8; % Conversation
% edgecolor{1} = facecolor{1}*0.7; % Conversation
edgecolor{1} = facecolor{1}*0.7; % Fiction
%edgecolor{3} = facecolor{3}*0.8; % Newspaper
edgecolor{2} = [0.80 0.00 1.00]; % Newspaper
edgecolor{3} = facecolor{3}*0.85; % Academic
c1 = find(double(y) == 1);
c2 = find(double(y) == 2);
c3 = find(double(y) == 3);
c4 = find(double(y) == 4);
linewidth = 1.0;

%% Plot figure 1
figure('Name','Complexity Measures','Units','centimeters',...
    'OuterPosition',[0 3 26.0 26.0],'Resize','off',...
    'PaperOrientation','landscape','PaperType','A4');
% Plot 1
axes('Position', [.095, .085, .87, .89],'ActivePositionProperty',...
    'position','FontName','Helvetica','FontSize',18.0);
hold all;
plot(X1(c1,1),X1(c1,2),'s','MarkerSize',markersize,'MarkerFaceColor',facecolor{1},'MarkerEdgeColor',edgecolor{1});
plot(X1(c2,1),X1(c2,2),'d','MarkerSize',markersize,'MarkerFaceColor',facecolor{2},'MarkerEdgeColor',edgecolor{2});
plot(X1(c3,1),X1(c3,2),'p','MarkerSize',markersize+2,'MarkerFaceColor',facecolor{3},'MarkerEdgeColor',edgecolor{3});
x11 = 0.0:0.05:0.2;
xlim([min(x11) max(x11)]);
set(gca,'XTick',x11);
x12 = 0.05:0.10:0.45;
ylim([min(x12) max(x12)]);
set(gca,'YTick',x12);
xlabel('Pronoun ratio');
ylabel('Noun ratio');

% Plot decision tree
plot([0.060 0.060],[0.000 0.500],'--k','LineWidth',linewidth); % 1
plot([0.000 0.060],[0.338 0.226],'--k','LineWidth',linewidth); % 2
plot([0.060 0.250],[0.148 0.148],'--k','LineWidth',linewidth); % 3
hold off;

legend({'Fiction','Newspaper','Academic',...
    'Decision-tree'},'Orientation','vertical','Location',...
    'NorthEast');
legend('boxoff');

%% Plot figure 2
figure('Name','Complexity Measures','Units','centimeters',...
    'OuterPosition',[0 3 26.0 26.0],'Resize','off',...
    'PaperOrientation','landscape','PaperType','A4');
% Plot 1
axes('Position', [.095, .085, .87, .89],'ActivePositionProperty',...
    'position','FontName','Helvetica','FontSize',18.0);
hold all;
plot(X2(c1,1),X2(c1,2),'s','MarkerSize',markersize,'MarkerFaceColor',facecolor{1},'MarkerEdgeColor',edgecolor{1});
plot(X2(c2,1),X2(c2,2),'d','MarkerSize',markersize,'MarkerFaceColor',facecolor{2},'MarkerEdgeColor',edgecolor{2});
plot(X2(c3,1),X2(c3,2),'p','MarkerSize',markersize+2,'MarkerFaceColor',facecolor{3},'MarkerEdgeColor',edgecolor{3});
x11 = 3.4:0.6:5.8;
xlim([min(x11) max(x11)]);
set(gca,'XTick',x11);
x12 = 0.40:0.08:0.72;
ylim([min(x12) max(x12)]);
set(gca,'YTick',x12);
xlabel('Average word length');
ylabel('Type/token ratio');

% Plot decision tree
plot([3.000 6.000],[0.369 0.745],'--k','LineWidth',linewidth); % 1
plot([4.562 4.562],[0.565 0.800],'--k','LineWidth',linewidth); % 2
plot([3.000 3.973],[0.614 0.491],'--k','LineWidth',linewidth); % 4
hold off;

legend({'Fiction','Newspaper','Academic',...
    'Decision-tree'},'Orientation','vertical','Location',...
    'NorthWest');
legend('boxoff');