function [Texts, POSs, nw] = readLOB(filepath,ntotaltexts)
% parse LOB text
text = fileread(filepath);
textline = regexp(text,'\n','split');

Texts = cell(ntotaltexts,1);
Text = {};
POSs = cell(ntotaltexts,1);
POS = {};
textnames = {};
ntexts = 0;
nwords = 0;
nw = zeros(ntotaltexts,1);
sindex = 0;
windex = 0;

for i = 1:length(textline)
    if(~isempty(textline{i}))
        % Check if new text starts
        textname = textline{i}(1:3);
        if(ntexts==0) % Start of first text
            % Create empty text
            ntexts = ntexts + 1;
            textnames{ntexts} = textname; %#ok<AGROW>
            Text = {};
            POS = {};
            sindex = 0;
            nwords = 0;
            % Create empty sentence
            sentence = {};
            pos = {};
            windex = 0;
        elseif(~strcmp(textname,textnames{ntexts})) % Start of new text
            % Store previous sentence
            Text{sindex} = sentence; %#ok<AGROW>
            POS{sindex} = pos; %#ok<AGROW>
            % Store previous text
            Texts{ntexts} = Text; 
            POSs{ntexts} = POS; 
            nw(ntexts) = nwords; 
            % Create empty text
            ntexts = ntexts + 1;
            textnames{ntexts} = textname; %#ok<AGROW>
            Text = {};
            POS = {};
            sindex = 0;
            nwords = 0;
            % Create empty sentence
            sentence = {};
            pos = {};
            windex = 0;
        end

        % Parse line
        match = regexp(textline{i}(9:end),'\S+','match');

        for j = 1:length(match)
            switch match{j}
                case '^'
                    % Store previous sentence
                    if(sindex > 0)
                        Text{sindex} = sentence; %#ok<AGROW>
                        POS{sindex} = pos; %#ok<AGROW>
                    elseif(~isempty(sentence))
                        sindex = sindex + 1;
                        Text{sindex} = sentence; %#ok<AGROW>
                        POS{sindex} = pos; %#ok<AGROW>
                    end
                    % Create empty sentence
                    sindex = sindex + 1;
                    sentence = {};
                    pos = {};
                    windex = 0;
                case '~'
                    %ignore
                otherwise
                    item = regexp(match{j},'_','split');
                    switch item{2}
                        case {'!','&FO','(',')','*''','**''',...
                                '*-',',','.','...',':',';','?'}
                            %ignore
                        otherwise
                            switch item{1}
                                case {'**[FOREIGN-QUOTATION**]','**[HEBREW.QUOTATION**]'}
                                    %ignore
                                otherwise
                                    windex = windex + 1;
                                    nwords = nwords + 1;
                                    sentence(windex) = cleanWord(item(1)); %#ok<AGROW>
                                    pos(windex) = item(2); %#ok<AGROW>
                            end
                    end
            end
        end
    end
end

% Store last sentence
Text{sindex} = sentence;
POS{sindex} = pos;
% Store last text
Texts{ntexts} = Text;
POSs{ntexts} = POS;
nw(ntexts) = nwords;
end

function word = cleanWord(word)
% remove markup annotation and strange character coding
% regexp special chars: [ \ ^ $ . | ? * + ( )
word = regexprep(word,'\\0',''); % Abbreviation
word = regexprep(word,'\*\+',char(163)); % Pound
word = regexprep(word,'\*@',char(176)); % Degree symbol
word = regexprep(word,'\*\*:',''); % End superscript
word = regexprep(word,'\*:',''); % Begin superscript
word = regexprep(word,'\*\?26',char(223)); % Latin Ezh
word = regexprep(word,'\*\?25',char(164)); % Infinity
word = regexprep(word,'\*\?24',char(222)); % Thorn
word = regexprep(word,'\*\?23',char(187)); % Right arrow
word = regexprep(word,'\*\?22',char(215)); % Square-root
word = regexprep(word,'\*\?20',char(161)); % Upside-down delta
word = regexprep(word,'\*\?19',char(208)); % h with stroke
word = regexprep(word,'\*\?18',char(247)); % Approx =
word = regexprep(word,'\*\?17',char(126)); % Tilde
word = regexprep(word,'\*\?16',char(133)); % Down arrow
word = regexprep(word,'\*\?14',char(177)); % Plus-minus
word = regexprep(word,'\*\?13',char(182)); % Paragraph symbol
word = regexprep(word,'\*\?9',char(179)); % Triple prime
word = regexprep(word,'\*\?8',char(178)); % Double prime
word = regexprep(word,'\*\?7',char(185)); % Single prime
% Changing previous character, ignore
word = regexprep(word,'\*\?21','');
word = regexprep(word,'\*\?15','');
word = regexprep(word,'\*\?12','');
word = regexprep(word,'\*\?11','');
word = regexprep(word,'\*\?10','');
word = regexprep(word,'\*\?6','');
word = regexprep(word,'\*\?5','');
word = regexprep(word,'\*\?4','');
word = regexprep(word,'\*\?3','');
word = regexprep(word,'\*\?2','');
word = regexprep(word,'\*\?1','');
word = regexprep(word,'"','');
end