function [Text, C5, POS, classCode, catRef, nwords] = readbncxml(filename)
%reads in one BNC-XML file and parses it into parts
% - Text: cell array of sentences, where each sentence is a cell array of
% words
% - C5: cell array of sentences, where each sentence is a cell array of
% C5 tags
% - POS: cell array of sentences, where each sentence is a cell array of
% POS tags
% - classCode: clean classCode attribute of the text
% - catRef: clean catRef attribute of the text

% Init
Text = cell(1);
C5 = cell(1);
POS = cell(1);
nwords = 0;

% Read in text
text = fileread(filename);

% Remove commented text from XML
cstart = strfind(text,'<!--');
cend = strfind(text,'-->');
for i = length(cstart):-1:1
    text(cstart(i):cend(i)+2) = [];
end

% Find XML markers
bopen = strfind(text,'<');
bclose = strfind(text,'>');
ntokens = length(bopen);

% Parse text
fti = [1 2]; % First two indices decide tag type
si = 0; % Sentence index

for i = 1:ntokens
    % Read text part
    part = text(bopen(i)+1:bclose(i)-1);
    % Parse text part
    if(length(part) >= 2)
        switch part(fti)
            case 'w ' % Word
                if(strcmp(part(end),'/'))
                    % Ignore empty words
                else
                    nwords = nwords + 1;
                    % Store word
                    wi = wi + 1;
                    stext{wi} = lower(strtrim(...
                        text(bclose(i)+1:bopen(i+1)-1))); %#ok<AGROW>
                    % Store C5 & POS tag
                    qi = strfind(part,'"');
                    c5i = strfind(part,'c5="');                    
                    c5istart = c5i(1)+4;
                    c5iend = qi(find(qi>c5istart,1,'first'))-1;
                    posi = strfind(part,'pos="');
                    posistart = posi(1)+5;
                    posiend = qi(find(qi>posistart,1,'first'))-1;
                    sc5{wi} = part(c5istart:c5iend); %#ok<AGROW>
                    spos{wi} = part(posistart:posiend); %#ok<AGROW>
                end
            case 's ' % Sentence
                stext = cell(1);
                sc5 = cell(1);
                spos = cell(1);
                si = si + 1;
                wi = 0;
            case '/s' % End of sentence
                if(strcmp(part,'/s') && wi>0)
                    Text{si} = stext;
                    C5{si} = sc5;
                    POS{si} = spos;
                end
            case 'ca' % catRef
                if(strcmp(part(1:6),'catRef'))
                    quotes = strfind(part,'"');
                    catRef = part(quotes(1)+1:quotes(2)-1);
                end
            case 'cl' % classCode
                if(strcmp(part(1:9),'classCode'))
                    classCode = strtrim(text(bclose(i)+1:bopen(i+1)-1));
                    i=i+1; %#ok<FXSET>
                end
        end
    end
end

end