% Produce statistics for all BNC texts
clear;

BNCPATH = '/Users/jlijffijt/Aalto/BNC/Texts/';

%% Init
ntexts = 4049;
C5tags =  {'AJ0','AJC','AJS','AT0','AV0','AVP','AVQ','CJC', ...
    'CJS','CJT','CRD','DPS','DT0','DTQ','EX0','ITJ','NN0', ...
    'NN1','NN2','NP0','ORD','PNI','PNP','PNQ','PNX','POS', ...
    'PRF','PRP','TO0','UNC','VBB','VBD','VBG','VBI','VBN', ...
    'VBZ','VDB','VDD','VDG','VDI','VDN','VDZ','VHB','VHD', ...
    'VHG','VHI','VHN','VHZ','VM0','VVB','VVD','VVG','VVI', ...
    'VVN','VVZ','XX0','ZZ0'};
POStags = {'ADJ','ADV','ART','CONJ','INTERJ','PREP','PRON', ...
    'SUBST','UNC','VERB'};
C5counts = zeros(ntexts,length(C5tags));
C52counts = zeros(ntexts,length(C5tags)^2);
POScounts = zeros(ntexts,length(POStags));
POS2counts = zeros(ntexts,length(POStags)^2);
POS3counts = zeros(ntexts,length(POStags)^3);
AWL = zeros(ntexts,1);
VWL = zeros(ntexts,1);
ASL = zeros(ntexts,1);
VSL = zeros(ntexts,1);
TUW = zeros(ntexts,1);
TTR = zeros(ntexts,1);
NHL = zeros(ntexts,1);
NDL = zeros(ntexts,1);
NTL = zeros(ntexts,1);
classCode = cell(ntexts,1);
catRef = cell(ntexts,1);
nwords = zeros(ntexts,1);

%% Create list of filenames
Texts = cell(ntexts,1);
count = 0;
primdir = dir(BNCPATH);
for i = 3:length(primdir)
    secdir = dir([BNCPATH primdir(i).name]);
    for j = 3:length(secdir)
        files = dir([BNCPATH primdir(i).name ...
            '/' secdir(j).name]);
        for k = 3:length(files)
            count = count + 1;
            Texts{count} = files(k).name;
        end
    end
end

clear i j k primdir secdir files count;

%% Compute statistics for all texts
windowsize = 250;
tic;
parfor i = 1:ntexts
    textname = Texts{i};
    textpath = [BNCPATH textname(1) '/' ...
                textname(1:2) '/' textname];
    
    % Read in the text
    [Text,C5,POS,cc,cr,nw] = readbncxml(textpath);
    classCode{i} = cc;
    catRef{i} = cr;
    nwords(i) = nw;
    
    % Compute C5 counts
    C5plain = C5simplify(C5);
    C5counts(i,:) = combFrequency(C5plain,C5tags,1);
    C52counts(i,:) = combFrequency(C5plain,C5tags,2);
    
    % Compute POS counts
    POScounts(i,:) = combFrequency(POS,POStags,1);
    POS2counts(i,:) = combFrequency(POS,POStags,2);
    POS3counts(i,:) = combFrequency(POS,POStags,3);
    
    % Compute other statistics
    [AWL(i), VWL(i), ASL(i), VSL(i), TUW(i), TTR(i), NHL(i), ...
        NDL(i), NTL(i)] = wordstatistics(Text, nwords(i), windowsize);
end
ctime = toc;

clear i textname textpath Text C5 POS cc cr nw C5plain;

%% Write to Matlab file
save statistics_ws250.mat
fprintf('%s\n',['Finished computing data with window size ' ...
    num2str(windowsize) ', in ' num2str(ctime/3600) ' hours.']);