% Produce statistics for all tagged LOB texts
%% Clear workspace
clear;

%% Init
windowsize = 250;
ntexts = 500;
Text = cell(ntexts,1);
POS = cell(ntexts,1);
nwords = zeros(ntexts,1);
genre = {'A: Press:reportage','B: Press:editorial',...
    'C: Press:reviews','D: Religion','E: Skills, trades, and hobbies',...
    'F: Popular lore','G: Belles lettres, biography, essays',...
    'H: Miscellaneous','J: Learned and scientific writings',...
    'K: General fiction','L: Mystery and detective fiction',...
    'M: Science fiction','N: Adventure and western fiction',...
    'P: Romance and love story','R: Humour'};
genreindex = [ones(44,1);repmat(2,27,1);repmat(3,17,1);...
    repmat(4,17,1);repmat(5,38,1);repmat(6,44,1);repmat(7,77,1);...
	repmat(8,30,1);repmat(9,80,1);repmat(10,29,1);repmat(11,24,1);...
    repmat(12,6,1);repmat(13,29,1);repmat(14,29,1);repmat(15,9,1)];
POStags = {'&FW','ABL','ABN','ABX','AP','AP"','AP$','APS','APS$','AT',...
    'ATI','BE','BED','BEDZ','BEG','BEM','BEN','BER','BEZ','CC','CC"',...
    'CD','CD$','CD-CD','CD1','CD1$','CD1S','CDS','CS','CS"','DO',...
    'DOD','DOZ','DT','DT$','DTI','DTS','DTX','EX','HV','HVD','HVG',...
    'HVN','HVZ','IN','IN"','JJ','JJ"','JJB','JJB"','JJR','JJR"',...
    'JJT','JJT"','JNP','MD','NC','NN','NN"','NN$','NNP','NNP$','NNPS',...
    'NNPS$','NNS','NNS"','NNS$','NNU','NNU"','NNUS','NP','NP$','NPL',...
    'NPL$','NPLS','NPLS$','NPS','NPS$','NPT','NPT"','NPT$','NPTS',...
    'NPTS$','NR','NR$','NRS','OD','PN','PN"','PN$','PN$"','PP$''PP$$',...
    'PP1A','PP1AS','PP1O','PP1OS','PP2','PP3','PP3A','PP3AS','PP3O',...
    'PP3OS','PPL','PPLS','PPLS"','QL','QLP','RB','RB"','RB$','RBR',...
    'RBT','RI','RN','RP','TO','TO"','UH','VB','VB"','VBD','VBG','VBN',...
    'VBZ','WDT','WDT"','WDTR','WP','WP$','WP$R','WPA','WPO','WPOR',...
    'WPR','WRB','XNOT','ZZ'};

%% Parse all texts
textdir = '/Users/jlijffijt/Aalto/Dammoc/TemporalDynamics/LOB/LOBTAG/';
files = dir(textdir);
files = files(3:end);
nfiles = length(files);
Textfile = cell(nfiles,1);
POSfile = cell(nfiles,1);
nwordsfile = cell(nfiles,1);

tic;
parfor i = 1:nfiles
    % Read text
    textpath = [textdir files(i).name];
    gindex = find(genreindex == i);
    [Textfile{i},POSfile{i},nwordsfile{i}] = readLOB(textpath,length(gindex));
end
for i = 1:nfiles
    gindex = find(genreindex == i);
    Text(gindex) = Textfile{i};
    POS(gindex) = POSfile{i};
    nwords(gindex) = nwordsfile{i};
end
ctime = toc;

fprintf('%s\n',['Corpus parsed in ' num2str(ctime/60) ' minutes.']);

clear textdir files nfiles Textfile POSfile nwordsfile i;
clear textpath gindex ctime;

%% Compute statistics
POScounts = zeros(ntexts,length(POStags));
AWL = zeros(ntexts,1);
VWL = zeros(ntexts,1);
ASL = zeros(ntexts,1);
VSL = zeros(ntexts,1);
TUW = zeros(ntexts,1);
TTR = zeros(ntexts,1);
NHL = zeros(ntexts,1);
NDL = zeros(ntexts,1);
NTL = zeros(ntexts,1);

for i = 1:ntexts
    POScounts(i,:) = combFrequency(POS{i},POStags,1);
    [AWL(i), VWL(i), ASL(i), VSL(i), TUW(i), TTR(i), NHL(i), NDL(i), ...
        NTL(i)] = wordstatistics(Text{i}, nwords(i), windowsize);
end

clear i Text POS;

%% Write to Matlab file
save statistics_LOB_ws250.mat