function [AWL, VWL, ASL, VSL, TUW, TTR, NHL, NDL, NTL] = ...
    wordstatistics(Text, nwords, windowsize)
%compute complexity statistics for a text
% - Text is assumed to be a 1-dim cell array of sentence, where each
% sentence is a 1-dim array of words
% - nwords is the number of words in Text

% Init
ns = length(Text);
sentlength = zeros(ns,1);
wordlength = zeros(nwords,1);
Uniquewords = cell(1,1);
TUW = 0;
wc = 0;
wordindex = zeros(nwords,1);

% Compute sentence and word lengths, unique word indices
for i = 1:ns
    % Load sentence
    S = Text{i};
    % Store sentence length
    sentlength(i) = length(S);
    for j = 1:length(S)
        % Load word
        word = S{j};
        wc = wc + 1;
        % Store word length
        wordlength(wc) = length(word);
        % Compute word index
        match = (strcmp(word,Uniquewords));
        if(any(match))
            wordindex(wc) = find(match);
        else
            TUW = TUW + 1;
            Uniquewords{TUW,1} = word;
            wordindex(wc) = TUW;
        end
    end
end

% Compute word and sentence statistics
AWL = mean(wordlength);
VWL = std(wordlength);
ASL = mean(sentlength);
VSL = std(sentlength);

% Compute TTR, NHL, NDL and NTL
if(nwords < windowsize) % Uncomputable for short text
    TTR = 0;
    NHL = 0;
    NDL = 0;
    NTL = 0;
    return;
end

nwindows = nwords - windowsize + 1;
ttrsamples = zeros(nwindows,1);
hapaxsamples = zeros(nwindows,1);
dissamples = zeros(nwindows,1);
trissamples = zeros(nwindows,1);
freq = zeros(TUW,1);
for i = 1:windowsize
    wi = wordindex(i);
    freq(wi) = freq(wi) + 1;
end
ttrsamples(1) = sum(freq > 0);
hapaxsamples(1) = sum(freq == 1);
dissamples(1) = sum(freq == 2);
trissamples(1) = sum(freq == 3);
for i = 1:nwindows-1
    wisubtract = wordindex(i);
    wiadd = wordindex(i+windowsize);
    freq(wisubtract) = freq(wisubtract) - 1;
    freq(wiadd) = freq(wiadd) + 1;
    ttrsamples(i+1) = sum(freq > 0);
    hapaxsamples(i+1) = sum(freq == 1);
    dissamples(i+1) = sum(freq == 2);
    trissamples(i+1) = sum(freq == 3);
end
TTR = mean(ttrsamples)./windowsize;
NHL = mean(hapaxsamples)./windowsize;
NDL = mean(dissamples)./windowsize;
NTL = mean(trissamples)./windowsize;

end